# LLMTranslator

[![PyPI version](https://img.shields.io/pypi/v/llmtranslator.svg)](https://pypi.python.org/pypi/llmtranslator)
[![Tests](https://github.com/rexwzh/llmtranslator/actions/workflows/test.yml/badge.svg)](https://github.com/rexwzh/llmtranslator/actions/workflows/test.yml/)
[![Documentation Status](https://img.shields.io/badge/docs-github_pages-blue.svg)](https://rexwzh.github.io/llmtranslator/)
[![Coverage](https://codecov.io/gh/rexwzh/llmtranslator/branch/main/graph/badge.svg)](https://codecov.io/gh/rexwzh/llmtranslator)

Text translator using OpenAI-like API.
